@@ -32,17 +32,6 @@ hd <- function(x, series = 1){
     }
   }
 
-  # function to create Z matrix
-  y_lag_cr <- function(y, lag_length){
-    # create matrix that stores the lags
-    y_lag <- matrix(NA, dim(y)[1],dim(y)[2]*lag_length)
-    for (i in 1:lag_length) {
-      y_lag[(1+i):dim(y)[1],((i*NCOL(y)-NCOL(y))+1):(i*NCOL(y))] <- y[1:(dim(y)[1]-i),(1:NCOL(y))]
-    }
-    # drop first observation
-    y_lag <- as.matrix(y_lag[-(1:lag_length),])
-    out <- list(lags = y_lag)
-  }
 
   # function to calculate impulse response
   IrF <- function(A_hat, B_hat, horizon){
@@ -111,7 +100,7 @@ hd <- function(x, series = 1){
 
   # calculating covariance from actual VAR
   A <- x$A_hat
-  Z <- t(y_lag_cr(y, p)$lags)
+  Z <- t(YLagCr(y, p))
 
   if(x$type == "const"){
     Z <- rbind(rep(1, ncol(Z)), Z)
